searchNodes=[{"doc":"PhxComponentHelpers are helper functions meant to be used within Phoenix LiveView live_components to make your components more configurable and extensible from your templates.It provides following features:set html attributes from component assignsset data attributes from component assignsset phx_* attributes from component assignsencode attributes as JSON from an Elixir structure assignvalidate mandatory attributesset and extend css classes from component assigns","ref":"PhxComponentHelpers.html","title":"PhxComponentHelpers","type":"module"},{"doc":"Extends assigns with class attributes.The class attribute will take provided default_classes as a default value and will be extended, on a class-by-class basis, by your assigns.Parametersassigns - your component assignsdefault_classes - the default classes that will be overridden by your assigns.Options:attribute - read &amp; write css classes from &amp; into this key:error_class - extra class that will be added if assigns contain form/field keys and field is faulty.Exampleassigns |&gt; extend_class(&quot;bg-blue-500 mt-8&quot;) |&gt; extend_class(&quot;py-4 px-2 divide-y-8 divide-gray-200&quot;, attribute: :wrapper_class) |&gt; extend_class(&quot;form-input&quot;, error_class: &quot;form-input-error&quot;, attribute: :input_class)assigns now contains @raw_class and @raw_wrapper_class.If your input assigns were %{class: &quot;mt-2&quot;, wrapper_class: &quot;divide-none&quot;} then:@raw_class would contain &quot;bg-blue-500 mt-2&quot;@raw_wrapper_class would contain &quot;py-4 px-2 divide-none&quot;","ref":"PhxComponentHelpers.html#extend_class/3","title":"PhxComponentHelpers.extend_class/3","type":"function"},{"doc":"Extends assigns with raw_* attributes that can be interpolated within your component markup.Parametersassigns - your component assignsattributes - a list of attributes (atoms) that will be fetched from assigns. Attributes can either be single atoms or tuples in the form {:atom, default} to provide default values.Options:required - raises if required attributes are absent from assigns:json - when true, will JSON encode the assign value:into - merges all assigns in a single one that can be interpolated at onceExampleassigns |&gt; set_component_attributes( [:id, :name, label: &quot;default label&quot;], required: [:id, :name], into: :attributes ) |&gt; set_component_attributes([:value], json: true)assigns now contains @raw_id, @raw_name, @raw_label and @raw_value. It also contains @raw_attributes which holds the values if :id, :name and :label.","ref":"PhxComponentHelpers.html#set_component_attributes/3","title":"PhxComponentHelpers.set_component_attributes/3","type":"function"},{"doc":"Extends assigns with raw_* data-attributes that can be interpolated within your component markup.Behaves exactly like set_component_attributes/3 excepted the output @raw_attr assigns contain data-attributes markup.Exampleassigns |&gt; set_data_attributes([:key, :text], required: [:key]) |&gt; set_data_attributes([:document], json: true)assigns now contains @raw_key, @raw_text and @raw_document.","ref":"PhxComponentHelpers.html#set_data_attributes/3","title":"PhxComponentHelpers.set_data_attributes/3","type":"function"},{"doc":"Extends assigns with form related attributes.If assigns contain :form and :field keys then it will set :id, :name, ':for', :value, and :errors from received Phoenix.HTML.Form.Parametersassigns - your component assignsExampleassigns |&gt; set_form_attributes()","ref":"PhxComponentHelpers.html#set_form_attributes/1","title":"PhxComponentHelpers.set_form_attributes/1","type":"function"},{"doc":"Just a convenient method built on top of set_prefixed_attributes/3 for phx attributes. It will automatically detect any attribute prefixed by phx_ from input assigns. By default, the :into option of set_prefixed_attributes/3 is :phx_attributesExampleassigns |&gt; set_phx_attributes(required: [:phx_submit], init: [:phx_change])assigns now contains @raw_phx_change, @raw_phx_submit and @raw_phx_attributes.","ref":"PhxComponentHelpers.html#set_phx_attributes/2","title":"PhxComponentHelpers.set_phx_attributes/2","type":"function"},{"doc":"Extends assigns with prefixed attributes that can be interpolated within your component markup. It will automatically detect any attribute prefixed by any of the given prefixes from input assigns.Can be used for intance to easily map alpinejs html attributes.Parametersassigns - your component assignsprefixes - a list of prefix as binariesOptions:init - a list of attributes that will be initialized if absent from assigns:required - raises if required attributes are absent from assigns:into - merges all assigns in a single one that can be interpolated at onceExampleassigns |&gt; set_prefixed_attributes( [&quot;@click&quot;, &quot;x-bind:&quot;], required: [&quot;x-bind:class&quot;], into: :alpine_attributes )assigns now contains @raw_click, @raw_x-bind:class and @raw_alpine_attributes.","ref":"PhxComponentHelpers.html#set_prefixed_attributes/3","title":"PhxComponentHelpers.set_prefixed_attributes/3","type":"function"},{"doc":"Validates that attributes are present in assigns. Raises an ArgumentError if any attribute is missing.Exampleassigns |&gt; validate_required_attributes([:id, :label])","ref":"PhxComponentHelpers.html#validate_required_attributes/2","title":"PhxComponentHelpers.validate_required_attributes/2","type":"function"},{"doc":"PhxComponentHelpers are helper functions meant to be used within Phoenix your views to facilitate usage of live_components inside templates.","ref":"PhxViewHelpers.html","title":"PhxViewHelpers","type":"module"},{"doc":"Extends Phoenix.HTML.Form.form_for/3 options to merge css class as with PhxComponentHelpers.extend_class/2.It's useful to define your own form_for functions with default css classes that still can be overriden from the template.Exampledef my_form_for(form_data, action, options) when is_list(options) do new_options = extend_form_class(options, &quot;mt-4 space-y-2&quot;) form_for(form_data, action, new_options) end","ref":"PhxViewHelpers.html#extend_form_class/2","title":"PhxViewHelpers.extend_form_class/2","type":"function"},{"doc":"PhxComponentHelpers","ref":"readme.html","title":"PhxComponentHelpers","type":"extras"},{"doc":"PhxComponentHelpers are helper functions meant to be used within Phoenix LiveView live_components to make your components more configurable and extensible from templates.It provides the following features:set HTML attributes from component assignsset data attributes from component assignsset phx_* attributes from component assignsset attributes with any custom prefix such as @click or x-bind: from alpinejsencode attributes as JSON from an Elixir structure assignvalidate mandatory attributesset and extend CSS classes from component assigns","ref":"readme.html#presentation","title":"PhxComponentHelpers - Presentation","type":"extras"},{"doc":"PhxComponentHelpers allows you to write components as such:defmodule Forms.Button do use Phoenix.LiveComponent import PhxComponentHelpers def mount(socket), do: {:ok, socket} def update(assigns, socket) do assigns = assigns |&gt; extend_class(&quot;bg-blue-700 hover:bg-blue-900 ...&quot;) |&gt; set_component_attributes([:type, :id, :label], required: [:id]) |&gt; set_phx_attributes() {:ok, assign(socket, assigns)} end def render(assigns) do ~L&quot;&quot;&quot; &lt;button &lt;%= @raw_id %&gt; &lt;%= @raw_type %&gt; &lt;%= @raw_phx_attributes %&gt; &lt;%= @raw_class %&gt;&gt; &lt;%= @label %&gt; &lt;/button&gt; &quot;&quot;&quot; end endFrom templates, it's looking like this:&lt;%= live_component @socket, Form, id: &quot;form&quot;, phx_submit: &quot;form_submit&quot;, class: &quot;divide-none&quot; do %&gt; &lt;%= live_component @socket, InputGroup do %&gt; &lt;%= live_component @socket, Label, for: &quot;name&quot;, label: &quot;Name&quot; %&gt; &lt;%= live_component @socket, TextInput, name: &quot;name&quot;, value: @my.name %&gt; &lt;% end %&gt; &lt;%= live_component @socket, ButtonGroup, class: &quot;pt-2&quot; do %&gt; &lt;%= live_component @socket, Button, type: &quot;submit&quot;, phx_click: &quot;btn-click&quot;, label: &quot;Save&quot; %&gt; &lt;% end %&gt; &lt;% end %&gt;","ref":"readme.html#example","title":"PhxComponentHelpers - Example","type":"extras"},{"doc":"PETAL stands for Phoenix - Elixir - TailwindCSS - Alpine.js - LiveView. In recent months it became quite popular in the Elixir ecosystem and PhxComponentHelpers are meant to fit in.TailwindCSS provides a new way to structure CSS but keeping a good HTML hygien required to rely on a component oriented library.Alpine.js is the Javascript counterpart of Tailwind. It let you define dynamic behaviour right from your templates with HTML attributes.The point of developping good components is to provide strong defaults in the component so that they can be used as-is. But also to let these defaults be overriden right from the templates.Here is the definition of a typical Form button, with Tailwind &amp; Alpine:defmodule Forms.Button do use Phoenix.LiveComponent import PhxComponentHelpers @css_class &quot;inline-flex items-center justify-center p-3 w-5 h-5 border \\ border-transparent text-2xl leading-4 font-medium rounded-md \\ text-white bg-primary hover:bg-primary-hover&quot; def mount(socket), do: {:ok, socket} def update(assigns, socket) do assigns = assigns |&gt; extend_class(@css_class) |&gt; set_phx_attributes() |&gt; set_prefixed_attributes( [&quot;@click&quot;, &quot;x-bind:&quot;], into: :alpine_attributes, required: &quot;@click&quot; ) {:ok, assign(socket, assigns)} end def render(assigns) do ~L&quot;&quot;&quot; &lt;button type=&quot;button&quot; &lt;%= @raw_class %&gt; &lt;%= @raw_alpine_attributes %&gt; &lt;%= @raw_phx_attributes%&gt; &gt; &lt;%= render_block(@inner_block) %&gt; &lt;/button&gt; &quot;&quot;&quot; end endThen in your html.leex template you can imagine the following code, providing @click behaviour and overriding just the few tailwind css classes you need (only p-*, w-* and h-* will be replaced). No phx behaviour here, but it's ok it won't break ;-)&lt;%= live_component @socket, Button, class: &quot;p-0 w-7 h-7&quot;, &quot;@click&quot;: &quot;$dispatch(&#39;closeslideover&#39;)&quot; do %&gt; &lt;%= live_component @socket, Icon, icon: :plus_circle %&gt; &lt;% end %&gt;","ref":"readme.html#with-the-petal-stack","title":"PhxComponentHelpers - With the PETAL stack","type":"extras"},{"doc":"This library also provides Phoenix.HTML.Form related functions so you can easily write your own my_form_for function with your css defaults.def my_form_for(form_data, action, options) when is_list(options) do new_options = extend_form_class(options, &quot;mt-4 space-y-2&quot;) form_for(form_data, action, new_options) endThen you only needs to use PhxComponentHelpers.set_form_attributes/3 within your own form LiveComponents in order to fetch names &amp; values from the form. Your template will then look like this:&lt;%= f = my_form_for @changeset, &quot;#&quot;, phx_submit: &quot;form_submit&quot;, class: &quot;divide-none&quot; do %&gt; &lt;%= live_component @socket, InputGroup do %&gt; &lt;%= live_component @socket, Label, form: f, field: :name, label: &quot;Name&quot; %&gt; &lt;%= live_component @socket, TextInput, form: f, field: :name %&gt; &lt;% end %&gt; &lt;%= live_component @socket, ButtonGroup, class: &quot;pt-2&quot; do %&gt; &lt;%= live_component @socket, Button, type: &quot;submit&quot;, label: &quot;Save&quot; %&gt; &lt;% end %&gt; &lt;% end %&gt;","ref":"readme.html#forms","title":"PhxComponentHelpers - Forms","type":"extras"},{"doc":"Surface is a library built on the top of Phoenix LiveView and live_components. Surface is much more ambitious and complex than PhxComponentHelpers is (which obviously isn't a framework, just helpers ...).Surface really changes the way you code user interfaces and components (you almost won't be using HTML templates anymore) whereas PhxComponentHelpers are just some sugar to help you using raw phoenix_live_view.","ref":"readme.html#compared-to-surface","title":"PhxComponentHelpers - Compared to Surface","type":"extras"},{"doc":"Available on https://hexdocs.pm","ref":"readme.html#documentation","title":"PhxComponentHelpers - Documentation","type":"extras"},{"doc":"Add the following to your mix.exs.def deps do [ {:phx_component_helpers, &quot;~&gt; 0.8.0&quot;}, {:jason, &quot;~&gt; 1.0&quot;} # only required if you want to use json encoding options ] end","ref":"readme.html#installation","title":"PhxComponentHelpers - Installation","type":"extras"}]